package com.xinelu.manage.service.signpatientpackagehardware;

import java.util.List;

import com.xinelu.manage.domain.signpatientpackagehardware.SignPatientPackageHardware;

/**
 * 签约患者服务包硬件信息Service接口
 *
 * @author xinelu
 * @date 2024-02-27
 */
public interface ISignPatientPackageHardwareService {
    /**
     * 查询签约患者服务包硬件信息
     *
     * @param id 签约患者服务包硬件信息主键
     * @return 签约患者服务包硬件信息
     */
    public SignPatientPackageHardware selectSignPatientPackageHardwareById(Long id);

    /**
     * 查询签约患者服务包硬件信息列表
     *
     * @param signPatientPackageHardware 签约患者服务包硬件信息
     * @return 签约患者服务包硬件信息集合
     */
    public List<SignPatientPackageHardware> selectSignPatientPackageHardwareList(SignPatientPackageHardware signPatientPackageHardware);

    /**
     * 新增签约患者服务包硬件信息
     *
     * @param signPatientPackageHardware 签约患者服务包硬件信息
     * @return 结果
     */
    public int insertSignPatientPackageHardware(SignPatientPackageHardware signPatientPackageHardware);

    /**
     * 修改签约患者服务包硬件信息
     *
     * @param signPatientPackageHardware 签约患者服务包硬件信息
     * @return 结果
     */
    public int updateSignPatientPackageHardware(SignPatientPackageHardware signPatientPackageHardware);

    /**
     * 批量删除签约患者服务包硬件信息
     *
     * @param ids 需要删除的签约患者服务包硬件信息主键集合
     * @return 结果
     */
    public int deleteSignPatientPackageHardwareByIds(Long[] ids);

    /**
     * 删除签约患者服务包硬件信息信息
     *
     * @param id 签约患者服务包硬件信息主键
     * @return 结果
     */
    public int deleteSignPatientPackageHardwareById(Long id);
}
